@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.093-24-g8e63070
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.094-17-gb48817e
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.094';
+our $VERSION = '0.095';
 
 use Moose;
 with
@@ -21,7 +21,7 @@ use Devel::CheckBin 'can_run';
 use Path::Tiny;
 use CPAN::Meta::Requirements;
 use Term::ANSIColor 'colored';
-use namespace::autoclean;
+use namespace::autoclean -also => ['_uniq'];
 
 sub mvp_multivalue_args { qw(installer copy_file_from_release) }
 
@@ -65,7 +65,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    _uniq($self->$orig(@_), qw(LICENSE CONTRIBUTING Changes));
+    _uniq($self->$orig(@_), qw(LICENSE CONTRIBUTING Changes ppport.h));
 };
 
 has changes_version_columns => (
@@ -140,6 +140,16 @@ sub configure
     warn '[@Author::ETHER] ' . colored('bin/ detected - should this be moved to script/, so its contents can be installed into $PATH?', 'bright_red') . "\n"
         if -d 'bin' and any { $_ eq 'ModuleBuildTiny' } $self->installer;
 
+    warn '[@Author::ETHER] You are using [ModuleBuild] as an installer, WTF?!'
+        if any { $_ eq 'ModuleBuild' } $self->installer;
+
+    # this is better than injecting a perl prereq for 5.008, to allow MBT to
+    # become more 5.006-compatible in the future without forcing the distribution to be re-released.
+    die 'Module::Build::Tiny should not be used in distributions that are targeting perl 5.006!'
+        if any { $_ eq 'ModuleBuildTiny' } $self->installer
+            and (not exists $self->payload->{'Test::MinimumVersion.max_target_perl'}
+                 or $self->payload->{'Test::MinimumVersion.max_target_perl'} < '5.008');
+
     my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
     my %removed; @removed{@$remove} = (!!1) x @$remove;
 
@@ -216,7 +226,7 @@ sub configure
             : ()
         } ],
         [ 'AuthorityFromModule' => { ':version' => '0.002' } ],
-        [ 'Authority'           => { authority => 'cpan:ETHER', do_munging => 0 } ],
+        [ 'Authority'           => { ':version' => '1.009', authority => 'cpan:ETHER', do_munging => 0 } ],
         [ 'MetaNoIndex'         => { directory => [ qw(t xt), grep { -d } qw(inc local perl5 fatlib examples share corpus demo) ] } ],
         [ 'MetaProvides::Package' => { ':version' => '1.15000002', finder => ':InstallModules', meta_noindex => 1, inherit_version => 0, inherit_missing => 0 } ],
         'MetaConfig',
@@ -254,7 +264,7 @@ sub configure
 
         # Before Release
         [ 'CheckStrictVersion'  => { decimal_only => 1 } ],
-        [ 'Git::Check'          => 'initial check' => { ':version' => '2.025', build_warnings => 1, allow_dirty => [''] } ],
+        [ 'Git::Check'          => 'initial check' => { allow_dirty => [''] } ],
         'Git::CheckFor::MergeConflicts',
         [ 'Git::CheckFor::CorrectBranch' => { ':version' => '0.004', release_branch => 'master' } ],
         [ 'Git::Remote::Check'  => { branch => 'master', remote_branch => 'master' } ],
@@ -378,7 +388,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.094
+version 0.095
 
 =head1 SYNOPSIS
 
@@ -526,6 +536,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [AuthorityFromModule]
     :version = 0.002
     [Authority]
+    :version = 1.009
     authority = cpan:ETHER
     do_munging = 0
 
@@ -603,8 +614,6 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     decimal_only = 1
 
     [Git::Check / initial check]
-    :version = 2.025
-    build_warnings = 1
     allow_dirty =
 
     [Git::CheckFor::MergeConflicts]
@@ -634,6 +643,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     filename = LICENSE
     filename = CONTRIBUTING
     filename = Changes
+    filename = ppport.h
 
     [Run::AfterRelease / remove old READMEs]
     :version = 0.038
@@ -648,6 +658,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     allow_dirty = README.pod
     allow_dirty = LICENSE
     allow_dirty = CONTRIBUTING
+    allow_dirty = ppport.h
     commit_msg = %N-%v%t%n%n%c
 
     [Git::Tag]
@@ -726,6 +737,8 @@ many as you'd like), as described in L<Pod::Spell/ADDING STOPWORDS>:
 
     =for stopwords foo bar baz
 
+See also L<[Test::PodSpelling]|Dist::Zilla::Plugin::Test::PodSpelling/stopwords>.
+
 =head2 installer
 
 =for stopwords ModuleBuildTiny
@@ -878,13 +891,6 @@ I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Karen Etheridge.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Randy Stauner Сергей Романов
@@ -901,4 +907,11 @@ Randy Stauner <rwstauner@cpan.org>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Karen Etheridge.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
